@@ -5,13 +5,10 @@ from __future__ import annotations
 import pathlib
 import typing as t
 
-if t.TYPE_CHECKING:
-    from typing_extensions import TypeGuard
-
-    from vcspull.types import RawConfigDict
+from vcspull.types import RawConfigDict
 
 
-def is_valid_config(config: dict[str, t.Any]) -> TypeGuard[RawConfigDict]:
+def is_valid_config(config: dict[str, t.Any]) -> t.TypeGuard[RawConfigDict]:
     """Return true and upcast if vcspull configuration file is valid."""
     if not isinstance(config, dict):
         return False
